# bolt-raycast

[![GitHub Actions](https://github.com/vdvman1/bolt-raycast/workflows/CI/badge.svg)](https://github.com/vdvman1/bolt-raycast/actions)

> Easily generate raycasting functions for your datapack using bolt

## Installation

The package can be installed with `pip`. Note, you must have `beet`, `mecha` and `bolt` installed to use this package.

```bash
pip install bolt_raycast
```

---

License - [MIT](https://github.com/vdvman1/bolt-raycast/blob/main/LICENSE)

